@@ -31,13 +31,12 @@ class UrlLoader;
 class KonqFrame;
 namespace KParts
 {
-//TODO KF6: when removing compatibility with KF5, uncomment the line below
-//class NavigationExtension;
 class StatusBarExtension;
 }
 
 namespace Konq {
     class PlaceholderPart;
+    class ViewType;
 }
 
 // TODO: make the history-handling code reuseable (e.g. in kparts) for people who want to use a
@@ -50,7 +49,7 @@ struct HistoryEntry {
     QString locationBarURL; // can be different from url when showing a index.html
     QString title;
     QByteArray buffer;
-    QString strServiceType;
+    QString strViewType;
     QString strServiceName;
     QByteArray postData;
     QString postContentType;
@@ -85,7 +84,7 @@ public:
      * @param service the service implementing the part
      * @param partServiceOffers list of part offers found by the factory
      * @param appServiceOffers list of app offers found by the factory
-     * @param serviceType the serviceType implemented by the part
+     * @param type the part capability or mimetype
      * @param passiveMode whether to initially make the view passive
      */
     KonqView(KonqViewFactory &viewFactory,
@@ -94,12 +93,20 @@ public:
              const KPluginMetaData &service,
              const QVector<KPluginMetaData> &partServiceOffers,
              const KService::List &appServiceOffers,
-             const QString &serviceType,
+             const Konq::ViewType &type,
              bool passiveMode);
 
     ~KonqView() override;
 
-    bool isWebEngineView() const;
+    /**
+     * Returns whether devtools (inspect element, etc.) is available for this view.
+     *
+     * This is determined by checking whether the part for this view
+     * has a method `setInspectedPart(KParts::ReadOnlyPart *)`.
+     *
+     * @return @b true if devtools is available for this view, @b false otherwise.
+     */
+    bool isDevtoolsAvailable() const;
 
     /**
      * Displays another URL, but without changing the view mode (caller has to
@@ -121,13 +128,13 @@ public:
      * Change the part inside this view if necessary.
      * Contract: the caller should call stop() first.
      *
-     * @param mimeType the mime type we want to show
+     * @param type the type we want to show
      * @param serviceName allows to enforce a particular service to be chosen,
      *        @see KonqFactory.
      * @param forceAutoEmbed
      * @param dontDeleteTemporaryFile
      */
-    bool changePart(const QString &mimeType,
+    bool changePart(const Konq::ViewType &type,
                     const QString &serviceName = QString(),
                     bool forceAutoEmbed = false);
 
@@ -239,24 +246,24 @@ public:
      * @brief The URL the view was requested to display
      *
      * This will be the same as the part's URL except when the URL was downloaded using
-     * a part's \link KonqInterfaces::DownloaderExtension DownloaderExtension\endlink. In this case, this will be the URL the user originally
+     * a KonqInterfaces::DownloadJob. In this case, this will be the URL the user originally
      * requested, while realUrl() is the URL of the downloaded file.
      *
      * @return the URL the view was requested to display
      * @see realUrl()
-     * @see KonqInterfaces::DownloaderExtension
+     * @see KonqInterfaces::DownloadJob
      */
     QUrl url() const {return m_requestedUrl;};
 
     /**
      * @brief The real URL displayed in the view
      *
-     * If the URL represents a file which has been downloaded using a part's
-     * \link KonqInterfaces::DownloaderExtension DownloaderExtension\endlink before being displayed, then the real URL is the local
+     * If the URL represents a file which has been downloaded using a
+     * KonqInterfaces::DownloadJob before being displayed, then the real URL is the local
      * file the URL was downloaded to. In all other cases, this is the same as url().
-     * @return the URL of the local file where a file was downloaded by a part's \link KonqInterfaces::DownloaderExtension DownloaderExtension\endlink
-     * or url() if the URL wasn't downloaded using \link KonqInterfaces::DownloaderExtension DownloaderExtension\endlink
-     * @see KonqInterfaces::DownloaderExtension
+     * @return the URL of the local file where a file was downloaded by a KonqInterfaces::DownloadJob
+     * and url() otherwise
+     * @see KonqInterfaces::DownloadJob
      */
     QUrl realUrl() const;
 
@@ -329,7 +336,7 @@ public:
         return m_bAborted;
     }
 
-    KParts::NavigationExtension *browserExtension() const;
+    KParts::NavigationExtension *navigationExtension() const;
 
     KParts::StatusBarExtension *statusBarExtension() const;
 
@@ -342,27 +349,33 @@ public:
     }
 
     /**
-     * @return the servicetype this view is currently displaying
-     * This is usually a mimetype, but it can be "Browser/View"
+     * @return the view type this view is currently displaying
+     * This is usually a mimetype, but it could also be the part
+     * capability `KParts::BrowserView`
      * for toggle views like the sidebar or the embedded konsole.
+     * It should never be `KParts::ReadOnlyPart`, because all parts have this capability,
+     * or `KParts::ReadWritePart`
      */
-    QString serviceType() const
+    Konq::ViewType type() const
     {
-        return m_serviceType;
+        return m_type;
     }
 
     /**
      * The mimetype this view is currently displaying.
-     * Can be invalid, if serviceType() is not a mimetype.
+     * Can be invalid, if type() is a part capability
      */
     QMimeType mimeType() const;
 
     /**
      * @return the servicetypes this view is capable to display
      */
-    QStringList serviceTypes() const
-    {
-        return Konq::serviceTypes(m_service);
+    // QStringList serviceTypes() const
+    // {
+    //     return Konq::serviceTypes(m_service);
+    // }
+    KParts::PartCapabilities partCapabilities() const {
+        return Konq::partCapabilities(m_service);
     }
 
     /**
@@ -371,19 +384,6 @@ public:
      */
     bool supportsMimeType(const QString &mimeType) const;
 
-    //TODO: it seems to be unused. Check and remove it
-    /**
-     * Whether the view in this part is suitable for web browsing.
-     *
-     * @return @b true if the part is suitable for browsing and @b false otherwise
-     *
-     * @warning Unfortunately, as far as I know, there's no way to detect whether a part is
-     * suitable for browsing. This function works by hardcoding the component names of such
-     * parts (currently only khtml, kwebkitpart and webenginepart). If other browsing parts
-     * will be added, the list should be changed or another way must be found.
-     **/
-    bool isWebBrowsingPart() const;
-
     // True if showing a directory
     bool showsDirectory() const;
 
@@ -524,7 +524,7 @@ public:
 
     // Called before reloading this view. Sets args.reload to true, and offers to repost form data.
     // Returns false in case the reload must be canceled.
-    bool prepareReload(KParts::OpenUrlArguments &args, BrowserArguments &browserArgs, bool softReload);
+    bool prepareReload(KParts::OpenUrlArguments &args, BrowserArguments &browserArgs);
 
     // overload for the QString version
     void setLocationBarURL(const QUrl &locationBarURL);
@@ -574,7 +574,9 @@ public:
      * while the part-specific information is stored in #m_delayedLoadingData.
      *
      * This function allows to load the content of the view only when it actually becomes visible
-     * @param mimeType the mimetype of the URL
+     * @param type the view type. It most likely be the mimetype of the URL, but in theory
+     * it could also be `KParts::PartCapability::BrowserView`. Currently, this shouldn't happen
+     * as toggable views can't be delayed (currently, at least)
      * @param serviceName the id of the part to use
      * @param openUrl whether an URL should be loaded when the part will be created
      * @param url the URL to load when the part will be created
@@ -582,7 +584,7 @@ public:
      * @param grp the object to read configuration options from
      * @param prexfix the prefix to add to configuration options names when reading from @p grp
      */
-    void storeDelayedLoadingData(const QString &mimeType, const QString &serviceName, bool openUrl, const QUrl &url,
+    void storeDelayedLoadingData(const Konq::ViewType &type, const QString &serviceName, bool openUrl, const QUrl &url,
                                  bool lockedLocation, const KConfigGroup &grp, const QString &prefix);
 
     /**
@@ -786,7 +788,7 @@ private:
     QVector<KPluginMetaData> m_partServiceOffers;
     KService::List m_appServiceOffers;
     KPluginMetaData m_service;
-    QString m_serviceType;
+    Konq::ViewType m_type;
     QString m_caption;
     QString m_tempFile;
     QString m_dbusObjectPath;
